#ifndef __MAGNATUNE_H__
#define __MAGNATUNE_H__

void magnatune_db_destroy(void);
void magnatune_db_init();
void magnatune_db_open();
gboolean magnatune_db_has_data();
MpdData * magnatune_db_get_genre_list();
void magnatune_db_download_xml(ProgressCallback cb, gpointer data );
gchar *magnatune_db_get_value(const char *artist, const char *album, int type);
MpdData * magnatune_db_get_album_list(char *wanted_genre,char *wanted_artist);
MpdData * magnatune_db_get_artist_list(char *genre);

GList * magnatune_db_get_url_list(const char *wanted_genre,const char *wanted_artist, const char *wanted_album);
MpdData* magnatune_db_get_song_list(const char *wanted_genre,const char *wanted_artist, const char *wanted_album);
#endif
